# Regexator

Creates the inverse of transliterated string to a regex. What? Basically, a regex that is diacritic insensitive

## Why?

Sometimes you are looking for **déja vu**, but your database is dumb and doesn't understand collations and diacritic insensitiveness, but it can compare stuff using regex, so there ya go.

## How?

Suppose you have the word **résumé** but written improperly in the database as
**resume**. The user is clever, and types it correctly into the search box. Gets
nothing. How to search for all the weird cases people mistype stuff when comes
to accents?
In the same way, you're looking for **Charles de Gaulle** or **Dont'a
Hightower** but you can't remember
where the spaces are. You'll be able to find them even if you're looking for
**Charles degaulle** or **Donta Hightower**

The optional 'strong' option converts all characters, including consonants.

The optional 'spaces' option includes a space or a dash(-) or a single quotation
mark (') between each characters

```es6
import { toRegex } from 'regexator';

toRegex()('résumé'); // => /r[eEÉéÈèÊêëË]s[úùÚÙüÜuU]m[eEÉéÈèÊêëË]/i;

toRegex({ flags: 'mu' })('résumé'); // => /r[eEÉéÈèÊêëË]s[úùÚÙüÜuU]m[eEÉéÈèÊêëË]/mu;

toRegex({
  flags: '',
  mappings: {
    e: 'eéÉ',
  },
})('résumé'); // => /r[eéÉ]s[úùÚÙüÜuU]m[eéÉ]/;

toRegex({}, 'strong')('résumé'); // => /[RrŔŕŖŗŘřȐȑȒȓṘṙṚṛṜṝṞṟ][EeÈèÉéÊêËëĒēĔĕĖėĘęĚěȄȅȆȇȨȩḔḕḖḗḘḙḚḛḜḝẸẹẺẻẼẽẾếỀềỂểỄễỆệ][SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ][UuÙùÚúÛûÜüŨũŪūŬŭŮůŰűŲųǓǔǕǖǗǘǙǚǛǜȔȕȖȗṲṳṴṵṶṷṸṹṺṻỤụỦủỨứỪừỬửỮữỰự][MmḾḿṀṁṂṃ][EeÈèÉéÊêËëĒēĔĕĖėĘęĚěȄȅȆȇȨȩḔḕḖḗḘḙḚḛḜḝẸẹẺẻẼẽẾếỀềỂểỄễỆệ]/i

toRegex({}, '', 'spaces')('résumé'); // => /r(?:\s|'|-)*[EeÈèÉéÊêËë](?:\s|'|-)*s(?:\s|'|-)*[UuÙùÚúÛûÜü](?:\s|'|-)*m(?:\s|'|-)*[EeÈèÉéÊêËë]/i

toRegex({}, 'strong', 'spaces')('résumé'); // => /[RrŔŕŖŗŘřȐȑȒȓṘṙṚṛṜṝṞṟ](?:\s|'|-)*[EeÈèÉéÊêËëĒēĔĕĖėĘęĚěȄȅȆȇȨȩḔḕḖḗḘḙḚḛḜḝẸẹẺẻẼẽẾếỀềỂểỄễỆệ](?:\[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ]|'|-)*[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ](?:\[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ]|'|-)*[UuÙùÚúÛûÜüŨũŪūŬŭŮůŰűŲųǓǔǕǖǗǘǙǚǛǜȔȕȖȗṲṳṴṵṶṷṸṹṺṻỤụỦủỨứỪừỬửỮữỰự](?:\[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ]|'|-)*[MmḾḿṀṁṂṃ](?:\[SsŚśŜŝŞşŠšȘșṠṡṢṣṤṥṦṧṨṩ]|'|-)*[EeÈèÉéÊêËëĒēĔĕĖėĘęĚěȄȅȆȇȨȩḔḕḖḗḘḙḚḛḜḝẸẹẺẻẼẽẾếỀềỂểỄễỆệ]/i
```

If you want to change the mappings for all instances:

```ts
import { charCodes } from 'regexator';

mappings['*'] = ['[\\S\\s]+'];
```

## Caveats

Be aware of [RegExp.prototype.exec](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/RegExp/exec) with `g` flag being stateful

The `i` flag is appended to the RegExp flags if you don't pass any flags to `toRegex`

## Compatibility

Work in node and the browser, but needs polyfills for `Array.reduce`, `Array.map` and `Object.keys` depending on how old your target browser is

## License

MIT
